#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai-json
version:              0.12.0
visibility:           public
id:                   hspec-wai-json-0.12.0-EEZkGHm18xOHFK1U8YkIVL
key:                  hspec-wai-json-0.12.0-EEZkGHm18xOHFK1U8YkIVL
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  998734b966dc52f667aad17d092bd386
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-wai-json-0.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-wai-json-0.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-wai-json-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.12.0-EEZkGHm18xOHFK1U8YkIVL
depends:
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4
    aeson-qq-0.8.4-Kam0HXlcY7O7suUvc2IzXt base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    hspec-wai-0.12.0-E6HYUnDLrKaBZt71Wsy1XL template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

